# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.models.long_term_auction import LongTermAuction

class TestLongTermAuction(unittest.TestCase):
    """LongTermAuction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LongTermAuction:
        """Test LongTermAuction
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LongTermAuction`
        """
        model = LongTermAuction()
        if include_optional:
            return LongTermAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '2022 May Auction',
                display_id = 'BDL-NL-GB-E-BASE---220305-01',
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                processing = True,
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00:00.000Z', 
                    to_mtu_end = '2022-01-04T11:00:00.000Z', ),
                allocation_mtu_size = 'MTU_15_MINS',
                allocation_resolution = 'RES_1_KW',
                bidding_configuration = empire_platform_api_public_client.models.auction_bidding_configuration.AuctionBiddingConfiguration(
                    mode = 'OPEN', 
                    pre_bidding_allowed = True, 
                    max_bids_per_participants = 0, 
                    min_bid_price = 1.337, ),
                process_steps = empire_platform_api_public_client.models.auction_process_steps_absolute.AuctionProcessStepsAbsolute(
                    preliminary_spec_publish = '2022-01-04T00:00:00.000Z', 
                    returns_window_close = '2022-01-04T00:00:00.000Z', 
                    final_spec_publish = '2022-01-04T00:00:00.000Z', 
                    bidding_open = '2022-01-04T00:00:00.000Z', 
                    show_bids_for_open_auctions = '2022-01-04T00:00:00.000Z', 
                    bidding_close = '2022-01-04T00:00:00.000Z', 
                    provisional_results_publish = '2022-01-04T00:00:00.000Z', 
                    final_results_publish = '2022-01-04T00:00:00.000Z', ),
                offered_capacity = empire_platform_api_public_client.models.long_term_offered_capacity.LongTermOfferedCapacity(
                    preliminary_oc = 56, 
                    returned_oc = 56, 
                    final_oc = 56, ),
                reserve_price = empire_platform_api_public_client.models.long_term_reserve_price.LongTermReservePrice(
                    steps = [
                        empire_platform_api_public_client.models.long_term_reserve_price_steps.LongTermReservePrice_steps(
                            from = 56, 
                            to = 56, 
                            reserve_price = 1.337, )
                        ], 
                    publish = 'PRELIMINARY_SPEC_PUBLISHED', )
            )
        else:
            return LongTermAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '2022 May Auction',
                display_id = 'BDL-NL-GB-E-BASE---220305-01',
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                processing = True,
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00:00.000Z', 
                    to_mtu_end = '2022-01-04T11:00:00.000Z', ),
                allocation_mtu_size = 'MTU_15_MINS',
                allocation_resolution = 'RES_1_KW',
                bidding_configuration = empire_platform_api_public_client.models.auction_bidding_configuration.AuctionBiddingConfiguration(
                    mode = 'OPEN', 
                    pre_bidding_allowed = True, 
                    max_bids_per_participants = 0, 
                    min_bid_price = 1.337, ),
                process_steps = empire_platform_api_public_client.models.auction_process_steps_absolute.AuctionProcessStepsAbsolute(
                    preliminary_spec_publish = '2022-01-04T00:00:00.000Z', 
                    returns_window_close = '2022-01-04T00:00:00.000Z', 
                    final_spec_publish = '2022-01-04T00:00:00.000Z', 
                    bidding_open = '2022-01-04T00:00:00.000Z', 
                    show_bids_for_open_auctions = '2022-01-04T00:00:00.000Z', 
                    bidding_close = '2022-01-04T00:00:00.000Z', 
                    provisional_results_publish = '2022-01-04T00:00:00.000Z', 
                    final_results_publish = '2022-01-04T00:00:00.000Z', ),
                offered_capacity = empire_platform_api_public_client.models.long_term_offered_capacity.LongTermOfferedCapacity(
                    preliminary_oc = 56, 
                    returned_oc = 56, 
                    final_oc = 56, ),
        )
        """

    def testLongTermAuction(self):
        """Test LongTermAuction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
