# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.models.bidding_configuration_secondary_market_notices import BiddingConfigurationSecondaryMarketNotices

class TestBiddingConfigurationSecondaryMarketNotices(unittest.TestCase):
    """BiddingConfigurationSecondaryMarketNotices unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BiddingConfigurationSecondaryMarketNotices:
        """Test BiddingConfigurationSecondaryMarketNotices
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BiddingConfigurationSecondaryMarketNotices`
        """
        model = BiddingConfigurationSecondaryMarketNotices()
        if include_optional:
            return BiddingConfigurationSecondaryMarketNotices(
                long_term = True,
                day_ahead = True,
                intra_day = True
            )
        else:
            return BiddingConfigurationSecondaryMarketNotices(
                long_term = True,
                day_ahead = True,
                intra_day = True,
        )
        """

    def testBiddingConfigurationSecondaryMarketNotices(self):
        """Test BiddingConfigurationSecondaryMarketNotices"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
