# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.default_bid_api import DefaultBidApi


class TestDefaultBidApi(unittest.TestCase):
    """DefaultBidApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultBidApi()

    def tearDown(self) -> None:
        pass

    def test_create_day_ahead_or_intra_day_default_bid(self) -> None:
        """Test case for create_day_ahead_or_intra_day_default_bid

        """
        pass

    def test_create_long_term_default_bid(self) -> None:
        """Test case for create_long_term_default_bid

        """
        pass

    def test_delete_default_bid(self) -> None:
        """Test case for delete_default_bid

        """
        pass

    def test_get_day_ahead_or_intra_day_default_bid(self) -> None:
        """Test case for get_day_ahead_or_intra_day_default_bid

        """
        pass

    def test_get_default_bid_options(self) -> None:
        """Test case for get_default_bid_options

        """
        pass

    def test_get_default_bids(self) -> None:
        """Test case for get_default_bids

        """
        pass

    def test_get_long_term_default_bid(self) -> None:
        """Test case for get_long_term_default_bid

        """
        pass

    def test_update_day_ahead_or_intra_day_default_bid(self) -> None:
        """Test case for update_day_ahead_or_intra_day_default_bid

        """
        pass

    def test_update_long_term_default_bid(self) -> None:
        """Test case for update_long_term_default_bid

        """
        pass


if __name__ == '__main__':
    unittest.main()
