# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AuctionTimescale(str, Enum):
    """
    Shorthand grouping of similar `AuctionProductType` - `LONG_TERM = [LT_EXPLICIT_MULTI_ANNUAL, LT_EXPLICIT_ANNUAL, LT_EXPLICIT_SEASONAL, LT_EXPLICIT_QUARTERLY, LT_EXPLICIT_MONTHLY, LT_EXPLICIT_MULTIDAY, LT_EXPLICIT_WEEKLY, LT_EXPLICIT_WEEKEND, LT_EXPLICIT_LONG_WEEKEND]` - `DAY_AHEAD = [DA_EXPLICIT_DA]` - `INTRA_DAY = [ID_EXPLICIT_ID_1, ID_EXPLICIT_ID_2, ID_EXPLICIT_ID_3, ID_EXPLICIT_ID_4]` 
    """

    """
    allowed enum values
    """
    LONG_TERM = 'LONG_TERM'
    DAY_AHEAD = 'DAY_AHEAD'
    INTRA_DAY = 'INTRA_DAY'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AuctionTimescale from a JSON string"""
        return cls(json.loads(json_str))


