# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.models.default_nomination_declaration_type import DefaultNominationDeclarationType

class TestDefaultNominationDeclarationType(unittest.TestCase):
    """DefaultNominationDeclarationType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDefaultNominationDeclarationType(self):
        """Test DefaultNominationDeclarationType"""
        # inst = DefaultNominationDeclarationType()

if __name__ == '__main__':
    unittest.main()
