# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.secondary_market_api import SecondaryMarketApi


class TestSecondaryMarketApi(unittest.TestCase):
    """SecondaryMarketApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SecondaryMarketApi()

    def tearDown(self) -> None:
        pass

    def test_accept_secondary_market_transfer_request(self) -> None:
        """Test case for accept_secondary_market_transfer_request

        """
        pass

    def test_create_day_ahead_or_intra_day_secondary_market_noticeboard_entry(self) -> None:
        """Test case for create_day_ahead_or_intra_day_secondary_market_noticeboard_entry

        """
        pass

    def test_create_day_ahead_or_intra_day_secondary_market_transfer_request(self) -> None:
        """Test case for create_day_ahead_or_intra_day_secondary_market_transfer_request

        """
        pass

    def test_create_day_ahead_or_intraday_secondary_noticeboard_response(self) -> None:
        """Test case for create_day_ahead_or_intraday_secondary_noticeboard_response

        """
        pass

    def test_create_long_term_secondary_market_noticeboard_entry(self) -> None:
        """Test case for create_long_term_secondary_market_noticeboard_entry

        """
        pass

    def test_create_long_term_secondary_market_transfer_request(self) -> None:
        """Test case for create_long_term_secondary_market_transfer_request

        """
        pass

    def test_create_long_term_secondary_noticeboard_response(self) -> None:
        """Test case for create_long_term_secondary_noticeboard_response

        """
        pass

    def test_create_secondary_market_return_request(self) -> None:
        """Test case for create_secondary_market_return_request

        """
        pass

    def test_delete_noticeboard_entry(self) -> None:
        """Test case for delete_noticeboard_entry

        """
        pass

    def test_get_day_ahead_or_intra_day_secondary_market_noticeboard_entry(self) -> None:
        """Test case for get_day_ahead_or_intra_day_secondary_market_noticeboard_entry

        """
        pass

    def test_get_day_ahead_or_intra_day_secondary_market_transfer_request(self) -> None:
        """Test case for get_day_ahead_or_intra_day_secondary_market_transfer_request

        """
        pass

    def test_get_day_ahead_or_intra_day_secondary_market_transfer_request_options(self) -> None:
        """Test case for get_day_ahead_or_intra_day_secondary_market_transfer_request_options

        """
        pass

    def test_get_day_ahead_or_intraday_secondary_market_noticeboard_options(self) -> None:
        """Test case for get_day_ahead_or_intraday_secondary_market_noticeboard_options

        """
        pass

    def test_get_day_ahead_or_intraday_secondary_market_noticeboard_response_options(self) -> None:
        """Test case for get_day_ahead_or_intraday_secondary_market_noticeboard_response_options

        """
        pass

    def test_get_long_term_secondary_market_noticeboard_entry(self) -> None:
        """Test case for get_long_term_secondary_market_noticeboard_entry

        """
        pass

    def test_get_long_term_secondary_market_noticeboard_options(self) -> None:
        """Test case for get_long_term_secondary_market_noticeboard_options

        """
        pass

    def test_get_long_term_secondary_market_noticeboard_response_options(self) -> None:
        """Test case for get_long_term_secondary_market_noticeboard_response_options

        """
        pass

    def test_get_long_term_secondary_market_transfer_request(self) -> None:
        """Test case for get_long_term_secondary_market_transfer_request

        """
        pass

    def test_get_long_term_secondary_market_transfer_request_options(self) -> None:
        """Test case for get_long_term_secondary_market_transfer_request_options

        """
        pass

    def test_get_secondary_market_noticeboard(self) -> None:
        """Test case for get_secondary_market_noticeboard

        """
        pass

    def test_get_secondary_market_return_request_options(self) -> None:
        """Test case for get_secondary_market_return_request_options

        """
        pass

    def test_get_secondary_market_return_requests(self) -> None:
        """Test case for get_secondary_market_return_requests

        """
        pass

    def test_get_secondary_market_transfer_requests(self) -> None:
        """Test case for get_secondary_market_transfer_requests

        """
        pass

    def test_reject_secondary_market_transfer_request(self) -> None:
        """Test case for reject_secondary_market_transfer_request

        """
        pass

    def test_withdraw_secondary_market_return_request(self) -> None:
        """Test case for withdraw_secondary_market_return_request

        """
        pass

    def test_withdraw_secondary_market_transfer_request(self) -> None:
        """Test case for withdraw_secondary_market_transfer_request

        """
        pass


if __name__ == '__main__':
    unittest.main()
