# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.models.default_bid_batch import DefaultBidBatch

class TestDefaultBidBatch(unittest.TestCase):
    """DefaultBidBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DefaultBidBatch:
        """Test DefaultBidBatch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DefaultBidBatch`
        """
        model = DefaultBidBatch()
        if include_optional:
            return DefaultBidBatch(
                entries = [
                    empire_platform_api_public_client.models.default_bid.DefaultBid(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        delivery_period_start = '2022-01-04T10:00:00.000Z', 
                        delivery_period_end = '2022-01-04T11:00:00.000Z', 
                        validity_period_start = '2022-01-04T00:00:00.000Z', 
                        validity_period_end = '2022-01-04T00:00:00.000Z', 
                        border_direction = 'GB_NL', 
                        status = 'ACTIVE', )
                    ],
                total_count = 0
            )
        else:
            return DefaultBidBatch(
                entries = [
                    empire_platform_api_public_client.models.default_bid.DefaultBid(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        delivery_period_start = '2022-01-04T10:00:00.000Z', 
                        delivery_period_end = '2022-01-04T11:00:00.000Z', 
                        validity_period_start = '2022-01-04T00:00:00.000Z', 
                        validity_period_end = '2022-01-04T00:00:00.000Z', 
                        border_direction = 'GB_NL', 
                        status = 'ACTIVE', )
                    ],
                total_count = 0,
        )
        """

    def testDefaultBidBatch(self):
        """Test DefaultBidBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
