# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.reporting_api import ReportingApi


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportingApi()

    def tearDown(self) -> None:
        pass

    def test_get_auction_allocation_results_report(self) -> None:
        """Test case for get_auction_allocation_results_report

        """
        pass

    def test_get_auctions_bids_report(self) -> None:
        """Test case for get_auctions_bids_report

        """
        pass

    def test_get_auctions_schedule_report(self) -> None:
        """Test case for get_auctions_schedule_report

        """
        pass

    def test_get_finance_auction_results_settlement_per_participant_report(self) -> None:
        """Test case for get_finance_auction_results_settlement_per_participant_report

        """
        pass

    def test_get_finance_billing_report(self) -> None:
        """Test case for get_finance_billing_report

        """
        pass

    def test_get_finance_bought_or_sold_capacity_report(self) -> None:
        """Test case for get_finance_bought_or_sold_capacity_report

        """
        pass

    def test_get_finance_credit_cover_report(self) -> None:
        """Test case for get_finance_credit_cover_report

        """
        pass

    def test_get_finance_credit_limit_report(self) -> None:
        """Test case for get_finance_credit_limit_report

        """
        pass

    def test_get_finance_invoice_details_report(self) -> None:
        """Test case for get_finance_invoice_details_report

        """
        pass

    def test_get_finance_invoice_pdfs(self) -> None:
        """Test case for get_finance_invoice_pdfs

        """
        pass

    def test_get_finance_invoice_status_report(self) -> None:
        """Test case for get_finance_invoice_status_report

        """
        pass

    def test_get_finance_single_invoice_details_report(self) -> None:
        """Test case for get_finance_single_invoice_details_report

        """
        pass

    def test_get_finance_uiosi_hourly_report(self) -> None:
        """Test case for get_finance_uiosi_hourly_report

        """
        pass

    def test_get_finance_uiosi_report(self) -> None:
        """Test case for get_finance_uiosi_report

        """
        pass

    def test_get_organisations_audit_logs_report(self) -> None:
        """Test case for get_organisations_audit_logs_report

        """
        pass

    def test_get_organisations_users_report(self) -> None:
        """Test case for get_organisations_users_report

        """
        pass

    def test_get_outages_curtailment_report(self) -> None:
        """Test case for get_outages_curtailment_report

        """
        pass

    def test_get_trs_and_nominations_buy_now_report(self) -> None:
        """Test case for get_trs_and_nominations_buy_now_report

        """
        pass

    def test_get_trs_and_nominations_overview_report(self) -> None:
        """Test case for get_trs_and_nominations_overview_report

        """
        pass

    def test_get_trs_and_nominations_proof_report(self) -> None:
        """Test case for get_trs_and_nominations_proof_report

        """
        pass


if __name__ == '__main__':
    unittest.main()
