# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.auction_api import AuctionApi


class TestAuctionApi(unittest.TestCase):
    """AuctionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuctionApi()

    def tearDown(self) -> None:
        pass

    def test_get_auction_bidding_configuration(self) -> None:
        """Test case for get_auction_bidding_configuration

        """
        pass

    def test_get_auction_overview(self) -> None:
        """Test case for get_auction_overview

        """
        pass

    def test_get_auction_reduction_periods(self) -> None:
        """Test case for get_auction_reduction_periods

        """
        pass

    def test_get_auctions(self) -> None:
        """Test case for get_auctions

        """
        pass

    def test_get_day_ahead_auction(self) -> None:
        """Test case for get_day_ahead_auction

        """
        pass

    def test_get_day_ahead_or_intra_day_auction_bidding_results(self) -> None:
        """Test case for get_day_ahead_or_intra_day_auction_bidding_results

        """
        pass

    def test_get_day_ahead_or_intra_day_auction_bids(self) -> None:
        """Test case for get_day_ahead_or_intra_day_auction_bids

        """
        pass

    def test_get_day_ahead_or_intra_day_auction_mtu_results(self) -> None:
        """Test case for get_day_ahead_or_intra_day_auction_mtu_results

        """
        pass

    def test_get_day_ahead_or_intra_day_auction_participant_results(self) -> None:
        """Test case for get_day_ahead_or_intra_day_auction_participant_results

        """
        pass

    def test_get_day_ahead_or_intra_day_auction_results(self) -> None:
        """Test case for get_day_ahead_or_intra_day_auction_results

        """
        pass

    def test_get_intra_day_auction(self) -> None:
        """Test case for get_intra_day_auction

        """
        pass

    def test_get_long_term_auction(self) -> None:
        """Test case for get_long_term_auction

        """
        pass

    def test_get_long_term_auction_bidding_results(self) -> None:
        """Test case for get_long_term_auction_bidding_results

        """
        pass

    def test_get_long_term_auction_bids(self) -> None:
        """Test case for get_long_term_auction_bids

        """
        pass

    def test_get_long_term_auction_results(self) -> None:
        """Test case for get_long_term_auction_results

        """
        pass

    def test_submit_day_ahead_or_intra_day_auction_bids(self) -> None:
        """Test case for submit_day_ahead_or_intra_day_auction_bids

        """
        pass

    def test_submit_long_term_auction_bids(self) -> None:
        """Test case for submit_long_term_auction_bids

        """
        pass


if __name__ == '__main__':
    unittest.main()
