# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.user_api import UserApi


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserApi()

    def tearDown(self) -> None:
        pass

    def test_get_user(self) -> None:
        """Test case for get_user

        """
        pass

    def test_get_users(self) -> None:
        """Test case for get_users

        """
        pass

    def test_resend_user_invite(self) -> None:
        """Test case for resend_user_invite

        """
        pass

    def test_revoke_user_invite(self) -> None:
        """Test case for revoke_user_invite

        """
        pass

    def test_suspend_user(self) -> None:
        """Test case for suspend_user

        """
        pass

    def test_unsuspend_user(self) -> None:
        """Test case for unsuspend_user

        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        """
        pass


if __name__ == '__main__':
    unittest.main()
